@@ -1,7 +1,7 @@
 package Perinci::CmdLine::Role::Help;
 
-our $DATE = '2014-08-26'; # DATE
-our $VERSION = '1.23'; # VERSION
+our $DATE = '2014-08-27'; # DATE
+our $VERSION = '1.24'; # VERSION
 
 # split here just so it's more organized
 
@@ -639,7 +639,7 @@ Perinci::CmdLine::Role::Help - Help-related routines
 
 =head1 VERSION
 
-This document describes version 1.23 of Perinci::CmdLine::Role::Help (from Perl distribution Perinci-CmdLine), released on 2014-08-26.
+This document describes version 1.24 of Perinci::CmdLine::Role::Help (from Perl distribution Perinci-CmdLine), released on 2014-08-27.
 
 =for Pod::Coverage ^(.+)$
 
@@ -660,7 +660,7 @@ Please visit the project's homepage at L<https://metacpan.org/release/Perinci-Cm
 
 =head1 SOURCE
 
-Source repository is at L<https://github.com/sharyanto/perl-Perinci-CmdLine>.
+Source repository is at L<https://github.com/perlancar/perl-Perinci-CmdLine>.
 
 =head1 BUGS
 
@@ -672,11 +672,11 @@ feature.
 
 =head1 AUTHOR
 
-Steven Haryanto <stevenharyanto@gmail.com>
+perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2014 by Steven Haryanto.
+This software is copyright (c) 2014 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
